# authentic2 - versatile identity manager
# Copyright (C) 2010-2019 Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.


try:
    import ldap
    from ldap.filter import filter_format  # noqa: F401
except ImportError:
    ldap = None

import logging

from django.core.management.base import BaseCommand

from authentic2.backends.ldap_backend import LDAPBackend


class Command(BaseCommand):
    def handle(self, *args, **kwargs):
        root_logger = logging.getLogger()
        ldap_logger = logging.getLogger('authentic2.backends.ldap_backend')

        # ensure log messages are displayed only once on terminal
        stream_handlers = [
            x for x in root_logger.handlers if isinstance(x, logging.StreamHandler) if x.stream.isatty()
        ]
        if stream_handlers:
            handler = stream_handlers[0]
        else:
            handler = logging.StreamHandler()
            ldap_logger.addHandler(handler)

        # add timestamp to messages
        formatter = logging.Formatter(fmt='%(asctime)s %(message)s', datefmt='%Y-%m-%d %H:%M:%S')
        handler.setFormatter(formatter)

        verbosity = int(kwargs['verbosity'])
        if verbosity == 1:
            ldap_logger.setLevel(logging.ERROR)
        elif verbosity == 2:
            ldap_logger.setLevel(logging.INFO)
        elif verbosity == 3:
            ldap_logger.setLevel(logging.DEBUG)

        for user in LDAPBackend.get_users():
            continue
